@@ -1,4 +1,3 @@
-import atexit
 import builtins
 import json
 from typing import List, Callable
@@ -7,20 +6,39 @@ old_print = builtins.print
 
 
 def merge_msg(msg, frame: bool = True) -> str:
-    if isinstance(msg, (list, dict)):
-        msg = f'{json.dumps(msg, indent=2, ensure_ascii=False)}'
-    elif isinstance(msg, tuple):
-        msg = f'{json.dumps(msg, indent=2, ensure_ascii=False)}'
-        msg = msg[1:-1]
-        if frame:
-            msg = f'({msg})'
-    else:
-        if isinstance(msg, str):
-            pass
-        else:
-            msg = str(msg)
-        if frame:
-            msg = f'[{msg}]'
+    if msg is None:
+        return 'null'
+
+    if not isinstance(msg, str):
+
+        is_bool = isinstance(msg, bool)
+        if is_bool:
+            return 'true' if msg else 'false'
+
+        is_tuple = isinstance(msg, tuple)
+        is_set = isinstance(msg, set)
+        if is_tuple or is_set:
+            msg = list(msg)
+
+        try:
+            msg = f'{json.dumps(msg, indent=2, ensure_ascii=False)}'
+            dump_msg = True
+        except:
+            dump_msg = False
+
+        if not dump_msg:
+            msg = f'{msg}'
+
+        if is_tuple or is_set:
+            msg = msg[1:-1]
+            if frame:
+                if is_tuple:
+                    msg = f'({msg})'
+                elif is_set:
+                    msg = f'{{{msg}}}'
+
+    elif frame:
+        msg = f'[{msg}]'
 
     return msg
 
